==> jc-1.4.0.tar.gz: java/awt/AWTException.h <==
// public class java.awt.AWTException

// class file dependencies
// @dep_class 1597dbbe4d84b2b3 java_awt_AWTException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_AWTException_H_
#define _JC_java_awt_AWTException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTException$sub_refs	_jc_java_awt_AWTException$sub_refs;
typedef struct _jc_java_awt_AWTException$sub_nonrefs	_jc_java_awt_AWTException$sub_nonrefs;
typedef struct _jc_java_awt_AWTException$refs	_jc_java_awt_AWTException$refs;
typedef struct _jc_java_awt_AWTException$nonrefs	_jc_java_awt_AWTException$nonrefs;
typedef struct _jc_java_awt_AWTException$object	_jc_java_awt_AWTException$object;

typedef struct _jc_java_awt_AWTException$fields_struct	_jc_java_awt_AWTException$fields_struct;
typedef const struct _jc_java_awt_AWTException$vmethods	_jc_java_awt_AWTException$vmethods;
typedef const struct _jc_java_awt_AWTException$vtable	_jc_java_awt_AWTException$vtable;
typedef const struct _jc_java_awt_AWTException$vtype	_jc_java_awt_AWTException$vtype;

// Class fields structure
struct _jc_java_awt_AWTException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_AWTException$fields_struct _jc_java_awt_AWTException$class_fields;

// Constructors
extern void _jc_java_awt_AWTException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_AWTException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_AWTException$vmethods {
};

// Vtable
struct _jc_java_awt_AWTException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_AWTException$vmethods	java_awt_AWTException;
};

// Vtype
struct _jc_java_awt_AWTException$vtype {
	_jc_type			type;
	_jc_java_awt_AWTException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTException$refs {
    _jc_java_awt_AWTException$sub_refs	java_awt_AWTException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_AWTException$sub_nonrefs	java_awt_AWTException;
};

// Object instance structure
struct _jc_java_awt_AWTException$object {
	_jc_java_awt_AWTException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTException$vtype	*vtype;
	_jc_java_awt_AWTException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTException$vtype _jc_java_awt_AWTException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTException$class_object;

#endif	/* _JC_java_awt_AWTException_H_ */

==> jc-1.4.6.tar.gz: java/awt/AWTException.h <==
// public class java.awt.AWTException

// class file dependencies
// @dep_class 1597dbbe4d84b2b3 java_awt_AWTException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_AWTException_H_
#define _JC_java_awt_AWTException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTException$sub_refs	_jc_java_awt_AWTException$sub_refs;
typedef struct _jc_java_awt_AWTException$sub_nonrefs	_jc_java_awt_AWTException$sub_nonrefs;
typedef struct _jc_java_awt_AWTException$refs	_jc_java_awt_AWTException$refs;
typedef struct _jc_java_awt_AWTException$nonrefs	_jc_java_awt_AWTException$nonrefs;
typedef struct _jc_java_awt_AWTException$object	_jc_java_awt_AWTException$object;

typedef struct _jc_java_awt_AWTException$fields_struct	_jc_java_awt_AWTException$fields_struct;
typedef const struct _jc_java_awt_AWTException$vmethods	_jc_java_awt_AWTException$vmethods;
typedef const struct _jc_java_awt_AWTException$vtable	_jc_java_awt_AWTException$vtable;
typedef const struct _jc_java_awt_AWTException$vtype	_jc_java_awt_AWTException$vtype;

// Class fields structure
struct _jc_java_awt_AWTException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_AWTException$fields_struct _jc_java_awt_AWTException$class_fields;

// Constructors
extern void _jc_java_awt_AWTException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_AWTException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_AWTException$vmethods {
};

// Vtable
struct _jc_java_awt_AWTException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_AWTException$vmethods	java_awt_AWTException;
};

// Vtype
struct _jc_java_awt_AWTException$vtype {
	_jc_type			type;
	_jc_java_awt_AWTException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTException$refs {
    _jc_java_awt_AWTException$sub_refs	java_awt_AWTException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_AWTException$sub_nonrefs	java_awt_AWTException;
};

// Object instance structure
struct _jc_java_awt_AWTException$object {
	_jc_java_awt_AWTException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTException$vtype	*vtype;
	_jc_java_awt_AWTException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTException$vtype _jc_java_awt_AWTException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTException$class_object;

#endif	/* _JC_java_awt_AWTException_H_ */
